/*!
 * © 2017 David Vines
 *
 * Creative Commons License
 *
 * This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 */
/* globals document, console, alert, Regiment, Rank, Club, SupportRow, RegimentRow, RankRow, ClubRow, PromoteRow, LocationRow, OtherRow, WeekRow, OffenderRow, DuelRow */

function showElement(id) {
    document.getElementById(id).style.display='';
}

function hideElement(id) {
    document.getElementById(id).style.display='none';
}

function expandCollapseSection(triangle,div) {
    var obj = document.getElementById(triangle);
    if(obj.className.indexOf('arrow-down')!==-1) {
        obj.className='arrow-right';
        hideElement(div);
    }
    else {
        obj.className='arrow-down';
        showElement(div);
    }
}

function setupRanks(cid) {
    var choice = document.getElementById(cid+"-rank");
    choice.length = 1; // Keep the blank first entry
    Rank.forEach(function(rank) {
        if (rank !== Rank.Private) {
            var option = document.createElement("option");
            option.text = rank.rank;
            choice.add(option);
        }
    });
}

function setupform(table, cid) {
    setupRanks(cid);

    var month = document.getElementById(cid+"-form-month").value;
    
    var contents = [];
    var notes = [];
    contents.Location = 'In Paris'; // default the location entry
    for(var row=table.firstElementChild.firstElementChild; row!==null; row=row.nextElementSibling) {
        contents[row.firstElementChild.textContent.trim()] = row.firstElementChild.nextElementSibling.textContent.trim();
        notes[row.firstElementChild.textContent.trim()] = row.firstElementChild.nextElementSibling.nextElementSibling.textContent.trim();
    }
    
    var sl = contents['Social Level'];
    var regimentEntry = contents['Regiment & Rank'];
    var oldregiment = (regimentEntry ? Regiment.forName(regimentEntry.split(',')[0].trim()) : null);
    var oldrank = (regimentEntry ? Rank.forName(regimentEntry.split(',')[1].trim()) : null);
    var oldclub = (contents.Club ? Club.forName(contents.Club) : null);
    var allowance = contents['Allowance and/or Pension'];
    var stable = contents.Stable;
    var inParis = document.getElementById(cid+"-location-paris");
    
    // set up location first (it may change the button settings and disable quite a few
    (new LocationRow(contents.Location,month,oldregiment,contents["Battle Outcome"])).activate(cid);
    
    // set up the offenders row
    (new OffenderRow(month,sl,contents.Endurance,contents.Offenders)).activate(cid);
    
    // set up the monthly rows
    (new SupportRow(sl,allowance,stable,contents['Female Companion'],notes['Female Companion'])).activate(cid);
    (new ClubRow(sl,oldregiment,oldclub)).activate(cid);
    (new RegimentRow(sl,oldregiment,oldrank,stable)).activate(cid);
    (new RankRow(sl,oldregiment,oldrank,stable)).activate(cid);
    
    // Setup weekly rows
    for(var wk=1; wk<=4; wk++) {
        (new DuelRow(wk,sl,contents.Endurance,contents['Duel Week '+wk],notes['Duel Week '+wk],
                contents['Rapier Expertise'],
                contents['Sabre Expertise'],
                contents['Cutlass Expertise'])
            ).activate(cid);
        (new WeekRow(wk,sl,oldclub,
                notes['Female Companion'],
                oldregiment,
                contents['Rapier Expertise'],
                contents['Sabre Expertise'],
                contents['Cutlass Expertise'])
        ).activate(cid);
    }
    
    //Set up the 'other' row
    (new OtherRow(oldrank,contents['Female Companion'])).activate(cid);
}

var djvengardeTables = document.querySelectorAll('[id^="djv-engarde-stats-"]');
for(var i=0; i<djvengardeTables.length; i++) {
    var characterId = djvengardeTables[i].id.split('-').pop();
    var form = document.getElementById('djv-engarde-'+characterId+'-order-form');
    if (form) {
        try {
            setupform(djvengardeTables[i],'djv-engarde-'+characterId);
        } catch (e) {
            /* jshint debug: true */
            debugger;
            if (e.stack) {
                alert(e + "\n\nStack Trace\n-----------------\n" + e.stack);
            } else {
                alert(e);
            }
        }
    } else {
        console.log("Only found "+djvengardeTables[i].id+" (characterId="+characterId+")");
    }
}