/*!
 * © 2017 David Vines
 *
 * Creative Commons License
 *
 * This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 */
/* globals Row, mistressExpense */
/* exported SupportRow */

function SupportRow(sl,allowance,stable,companion,cnotes) {
    Row.call(this);
    
    this._sl = sl;
    this._allowance = allowance;
    this._stable = stable;
    this._companion = companion;
    this._cnotes = cnotes;
    
}

SupportRow.prototype = Object.create(Row.prototype);

SupportRow.prototype.activate = function(cid) {
    Row.prototype.activate.call(this,cid);
    
    this._none = document.getElementById(cid+"-support-none");
    this._noneLabel = document.getElementById(cid+"-support-none-label");
    this._std = document.getElementById(cid+"-support-std");
    this._stdLabel = document.getElementById(cid+"-support-std-label");
    this._con = document.getElementById(cid+"-support-con");
    this._conLabel = document.getElementById(cid+"-support-con-label");
   
    this.controlledBy(this._none);
    this.controlledBy(this._std);
    this.controlledBy(this._con);
    
    this.addInnerHTML(document.getElementById(cid+"-support-effect"));
    this.addOrderField(document.getElementById(cid+"-form-support"));
    this.addNotesField(document.getElementById(cid+"-form-support-effect"));
    
    this.processChange();
};

SupportRow.prototype.processChange = function() {
    var stableCost = function(stable) {
        if (stable) {
            var horses = Number(stable.match(/\d+/)[0]);
            return horses*3+2;
        } else {
            return 0;
        }
    };
    var order;
    var notes;
    if (this._inParis.checked) {
        this.enable(this._none,this._noneLabel);
        this.enable(this._std,this._stdLabel);
        this.enable(this._con,this._conLabel);
        if (this._none.checked) {
            order = "None";
            notes = "0 Crowns spent of an income of "+this._allowance+" Crowns. <b>Social Level</b> will decrease by one.";
        } else if (this._std.checked) {
            order = "Standard";
            notes = ""+this._sl*2+" Crowns spent of an income of "+this._allowance+" Crowns.";
        } else {
            order = "Conspicious";
            notes = ""+this._sl*3+" Crowns spent of an income of "+this._allowance+" Crowns. 1 Status Point gained.";
        }
    } else {
        order = "Out of Paris";
        notes = "Out of Paris - no support costs - all your income of "+this._allowance+" Crowns will be saved.";
        this._none.checked = true;
        this.disable(this._none,this._noneLabel);
        this.disable(this._std,this._stdLabel);
        this.disable(this._con,this._conLabel);
        
    }
    if (this._stable) {
        notes += " Your stable of "+this._stable+" will cost an additional "+stableCost(this._stable)+" Crowns.";
    }
    if (this._companion) {
        var hersl = Number(this._cnotes.match(/\d+/)[0]);
        if (this._cnotes.indexOf("Wealthy") === -1) {
            notes += " Supporting "+this._companion+" will cost an additional "+(hersl*3)+" Crowns to keep her in the manner to which she is accustomed.";
        } else {
            if (hersl > this._sl) {
                notes += " "+this._companion+" makes small gifts to you worth a total of "+(hersl-this._sl)*2+" Crowns.";
            } else {
                notes += " "+this._companion+"'s wealth is able to keep her in the manner to which she is accustomed.";
            }
        }
        var gain = 1;
        if (this._cnotes.indexOf("Stunning") !== -1) {
            gain += 1;
        }
        if (hersl > this._sl) {
            gain += (hersl - this._sl);
        }
        notes += " You gain ";
        if (gain === 1) {
            notes += " a status point";
        } else {
            notes += ""+gain+" status points";
        }
        notes += " for being the companion of "+this._companion+" this month.";
    }

    this.disableIfOutOfParis(this._none,this._noneLabel);
    this.disableIfOutOfParis(this._std,this._stdLabel);
    this.disableIfOutOfParis(this._con,this._conLabel);

    this.notifyOrder(order);
    this.notifyCommentary(notes);
};
